@@ -267,6 +267,7 @@ void build_widgets()
 
    //  edit menu
    ch * rotate_tip = "Rotate or level image, upright, mirror";
+   ch * upright_tip = "Upright a rotated image with one button";
    ch * crop_tip = "Crop (trim) image margins";
    ch * retouch_tip = "Adjust brightness, contrast, color";
    ch * rescale_tip = "Change image pixel dimensions";
@@ -295,8 +296,7 @@ void build_widgets()
    ch * adjust_HSL_tip = "Adjust color using HSL colors";
    ch * color_profile_tip = "Convert image to another color profile";
    ch * remove_dust_tip = "Remove dust spots from old scanned photos";
-   ch * chromatic1_tip = "Fix color fringes in outer areas of an image";
-   ch * chromatic2_tip = "Fix color fringes on dark/bright feature edges";
+   ch * chromatic_tip = "Fix color fringes in outer areas of an image";
 
    //  refine menu
    ch * voodoo1_tip = "1-click auto improve that may be good enough";
@@ -323,6 +323,7 @@ void build_widgets()
    ch * texture_tip = "Add texture to an image";
    ch * pattern_tip = "Tile image with a repeating pattern";
    ch * dither_tip = "Convert image into dithered dots";
+   ch * blobs_tip = "Pixels aggregate and condense into blobs";
    ch * engrave_tip = "Convet image into black/white lines";
    ch * mosaic_tip = "Create a mosaic with tiles made from all images";
    ch * add_noise_tip = "Add random noise to an image";
@@ -386,7 +387,6 @@ void build_widgets()
    //  tools menu
    ch * index_tip = "Index new image files and make thumbnails";
    ch * quick_index_tip = "Quick incremental index update";
-   ch * move_fotoxx_home_tip = "Move Fotoxx home folder";
    ch * settings_tip = "User preferences and settings";
    ch * KB_shortcuts_tip = "Show or make Keyboard Shortcuts";
    ch * RGB_dist_tip = "Show RGB brightness distribution";
@@ -394,7 +394,6 @@ void build_widgets()
    ch * duplicates_tip = "Search all image files and report duplicates";
    ch * measure_image_tip = "Measure distances within an image";
    ch * show_RGB_tip = "Show RGB colors at mouse position";
-   ch * popup_text_tip = "Show text strings for edit insertion";
    ch * calib_printer_tip = "Calibrate printer colors";
    ch * grid_settings_tip = "Set grid line counts or spacing";
    ch * toggle_grid_tip = "Toggle grid lines on and off";
@@ -467,7 +466,7 @@ void build_widgets()
    MENU(mGallery,   "Gallery Screen", 0,      gallery_screen_tip,           m_gallery_screen, 0);
    MENU(mGallery,   "Gallery Home", 0,        gallery_home_tip,             navi::menufuncx, "Home" );
    MENU(mGallery,   "Gallery End", 0,         gallery_end_tip,              navi::menufuncx, "End" );
-   MENU(mGallery,   "Curr. Image Folder", 0,  image_folder_tip,             m_image_folder, 0 );
+   MENU(mGallery,   "Image Folder", 0,        image_folder_tip,             m_image_folder, 0 );
    MENU(mGallery,   "Folder Tree", 0,         folder_tree_tip,              m_folder_tree, 0 );
    MENU(mGallery,   "Select Files", 0,        select_files_tip,             m_select_files, 0 );
    MENU(mGallery,   "Rename Folder", 0,       rename_folder_tip,            m_rename_folder, 0 );
@@ -519,6 +518,7 @@ void build_widgets()
 
    mEdit = create_popmenu(); 
    MENU(mEdit,    "Rotate", 0,                rotate_tip,                   m_rotate, 0 );
+   MENU(mEdit,    "Upright", 0,               upright_tip,                  m_upright, 0 );
    MENU(mEdit,    "Crop", 0,                  crop_tip,                     m_crop, 0 );
    MENU(mEdit,    "Retouch", 0,               retouch_tip,                  m_retouch, 0 );
    MENU(mEdit,    "Rescale", 0,               rescale_tip,                  m_rescale, 0 );
@@ -547,8 +547,7 @@ void build_widgets()
    MENU(mRepair,     "Adjust HSL", 0,         adjust_HSL_tip,               m_adjust_HSL, 0 );
    MENU(mRepair,     "Color Profile", 0,      color_profile_tip,            m_color_profile, 0 );
    MENU(mRepair,     "Remove Dust", 0,        remove_dust_tip,              m_remove_dust, 0 );
-   MENU(mRepair,     "Chromatic 1", 0,        chromatic1_tip,               m_chromatic1, 0 );
-   MENU(mRepair,     "Chromatic 2", 0,        chromatic2_tip,               m_chromatic2, 0 );
+   MENU(mRepair,     "Chromatic", 0,          chromatic_tip,                m_chromatic, 0 );
 
    mRefine = create_popmenu();
    MENU(mRefine,     "Voodoo 1", 0,              voodoo1_tip,               m_voodoo1, 0 );
@@ -576,6 +575,7 @@ void build_widgets()
    MENU(mEffects,    "Texture", 0,               texture_tip,               m_texture, 0 );
    MENU(mEffects,    "Pattern", 0,               pattern_tip,               m_pattern, 0 );
    MENU(mEffects,    "Dither", 0,                dither_tip,                m_dither, 0 );
+   MENU(mEffects,    "Blobs", 0,                 blobs_tip,                 m_blobs, 0 );
    MENU(mEffects,    "Engrave", 0,               engrave_tip,               m_engrave, 0 );
    MENU(mEffects,    "Mosaic", 0,                mosaic_tip,                m_mosaic, 0 );
    MENU(mEffects,    "Add Noise", 0,             add_noise_tip,             m_add_noise, 0 );
@@ -639,7 +639,6 @@ void build_widgets()
    mTools = create_popmenu();
    MENU(mTools,   "Index Files", 0,              index_tip,                 m_index, 0 );
    MENU(mTools,   "Quick Index", 0,              quick_index_tip,           m_quick_index, 0 );
-   MENU(mTools,   "Move Fotoxx Home", 0,         move_fotoxx_home_tip,      m_move_fotoxx_home, 0 );
    MENU(mTools,   "Settings", 0,                 settings_tip,              m_settings, 0 );
    MENU(mTools,   "KB Shortcuts", 0,             KB_shortcuts_tip,          m_KB_shortcuts, 0 );
    MENU(mTools,   "RGB Distribution", 0,         RGB_dist_tip,              m_RGB_dist, 0 );
@@ -647,7 +646,6 @@ void build_widgets()
    MENU(mTools,   "Find Duplicates", 0,          duplicates_tip,            m_duplicates, 0 );
    MENU(mTools,   "Measure Image", 0,            measure_image_tip,         m_measure_image, 0 );
    MENU(mTools,   "Show RGB", 0,                 show_RGB_tip,              m_show_RGB, 0 );
-   MENU(mTools,   "Popup Text", 0,               popup_text_tip,            m_popup_text, 0 );
    MENU(mTools,   "Calibrate Printer", 0,        calib_printer_tip,         m_calibrate_printer, 0 );
    MENU(mTools,   "Grid Settings", 0,            grid_settings_tip,         m_grid_settings, 0 );
    MENU(mTools,   "Toggle_Grid", 0,              toggle_grid_tip,           m_toggle_grid, 0 );
@@ -703,7 +701,7 @@ void build_widgets()
       MENU(mDevmenu, "zmalloc report",    0, "show memory allocations by tag", m_zmalloc_report, 0);
       MENU(mDevmenu, "zmalloc growth",    0, "show memory growth by tag", m_zmalloc_growth, 0);
       MENU(mDevmenu, "mouse events",      0, "toggle: show mouse events popup text", m_mouse_events, 0);
-      MENU(mDevmenu, "Audit User Guide",  0, "check all user guide links", m_audit_userguide, 0);                       // 23.2
+      MENU(mDevmenu, "Audit User Guide",  0, "check all user guide links", m_audit_userguide, 0);
       MENU(mDevmenu, "Edit Template",     0, "edit function template for new code", m_template, 0);                     // 23.60
       MENU(0, "Dev-Tools", "devmenu.png", "developer tools", (cbFunc *) popup_menu, (ch *) mDevmenu);
    }
@@ -820,7 +818,6 @@ void build_widgets()
    KBshort("Open Image File",    m_open_file,               0     );
    KBshort("Permissions",        m_permissions,             0     );
    KBshort("Places/Dates",       m_meta_places_dates,       0     );
-   KBshort("Popup Text",         m_popup_text,              0     );
    KBshort("Settings",           m_settings,                0     );
    KBshort("Print Calibrated",   m_print_calibrated,        0     );
    KBshort("Print",              m_print,                   0     );
@@ -847,6 +844,7 @@ void build_widgets()
    KBshort("Toggle Captions",    m_meta_toggle_caps,        0     );
    KBshort("Toggle Grid",        m_toggle_grid,             0     );
    KBshort("Undo",               m_undo,                    0     );
+   KBshort("Upright",            m_upright,                 0     ); 
    KBshort("View 360° Pano",     m_view360,                 0     );
    KBshort("View Meta",          m_meta_view_short,         0     );
    KBshort("Voodoo 1",           m_voodoo1,                 0     );
