@@ -271,7 +271,7 @@ class HashTab
    int     cap;                                                                  //  table capacity
    int     count;                                                                //  strings contained
    int     cc;                                                                   //  string length
-   ch      *table;                                                                //  table[cc][cap]
+   ch      *table = 0;                                                           //  table[cc][cap]
 public:
    HashTab(int cc, int cap);                                                     //  constructor
    ~HashTab();                                                                   //  destructor
@@ -287,7 +287,7 @@ public:
 
 typedef struct {                                                                 //  list data type
    int      count;                                                               //  count of member strings
-   ch       **mber;                                                              //  member strings, null == missing
+   ch       **mber = 0;                                                          //  member strings, null == missing
 }  zlist_t;
 
 zlist_t * zlist_new(int count);                                                  //  create zlist with 'count' empty members
@@ -456,15 +456,15 @@ void popup_menu(GtkWidget *, GtkWidget *popmenu);
 //  create vertical menu/toolbar in vertical packing box
 
 struct vmenuent {                                                                //  menu data from caller
-   ch          *name;                                                            //  menu name, text
-   ch          *icon;                                                            //  opt. icon file name
-   ch          *desc;                                                            //  description (mouse hover popup)
+   ch          *name = 0;                                                        //  menu name, text
+   ch          *icon = 0;                                                        //  opt. icon file name
+   ch          *desc = 0;                                                        //  description (mouse hover popup)
    cbFunc      *LMfunc;                                                          //  menu func for left mouse click
    cbFunc      *RMfunc;                                                          //  menu func for right mouse click
    cbFunc      *setupfunc;                                                       //  opt. setup func for menu func
-   ch          *arg;                                                             //  callback arg for menu func
-   ch          *setuparg;                                                        //  callback arg for setup func
-   ch          *RMarg;                                                           //  callback arg for RMfunc
+   ch          *arg = 0;                                                         //  callback arg for menu func
+   ch          *setuparg = 0;                                                    //  callback arg for setup func
+   ch          *RMarg = 0;                                                       //  callback arg for RMfunc
    PIXBUF      *pixbuf;                                                          //  icon pixbuf or null
    PangoLayout *playout1, *playout2;                                             //  normal and bold menu text
    int         namex, namey;                                                     //  menu name position in layout
@@ -539,10 +539,10 @@ int      splcurve_save(spldat *sd, FILE *fid);
 #define zdialog_button_shortcuts "Done OK Cancel Apply Reset"                    //  buttons that may have KB shortcuts
 
 struct zwidget  {
-      ch          *type;                           //  hbox, vbox, label, entry ...
-      ch          *wname;                          //  widget name
-      ch          *pname;                          //  parent (container) name
-      ch          *data;                           //  widget data, initial / returned
+      ch          *type = 0;                       //  hbox, vbox, label, entry ...
+      ch          *wname = 0;                      //  widget name
+      ch          *pname = 0;                      //  parent (container) name
+      ch          *data = 0;                       //  widget data, initial / returned
       int         size;                            //  text entry cc or image pixel size
       int         homog;                           //  hbox/vbox: equal spacing flag
       int         expand;                          //  widget is expandable flag
@@ -558,7 +558,7 @@ struct zwidget  {
 struct zdialog  {
       int         sentinel1;                       //  validity sentinel1
       int         uniqueID;                        //  unique ID, monotone increasing
-      ch          *title;                          //  dialog title
+      ch          *title = 0;                      //  dialog title
       void        *eventCB;                        //  dialog event user callback function
       void        *popup_report_CB;                //  callback function for popup_report
       int         zrunning;                        //  dialog is running (0,1)
@@ -569,7 +569,7 @@ struct zdialog  {
       int         saveinputs;                      //  save and recall user inputs each use
       GtkWidget   *dialog;                         //  dialog window or null (box parent)
       GtkWidget   *parent;                         //  parent window or null
-      ch          *ptype;                          //  null or "window" or "box" parent
+      ch          *ptype = 0;                      //  null or "window" or "box" parent
       ch          *compbutton[zdmaxbutts];         //  dialog completion button labels
       GtkWidget   *compwidget[zdmaxbutts];         //  dialog completion button widgets
       zwidget     widget[zdmaxwidgets];            //  dialog widgets (EOF = type = 0)
@@ -659,7 +659,7 @@ void zdialog_popup_text(ch *textfile, GtkWidget *parent);
 //  write text report in popup window
 
 zdialog * popup_report_open(ch *title, GtkWidget *parent, int ww, int hh,        //  open popup report - pixel size,
-                       int Fheader, textwidget_callbackfunc_t CBfunc, ...);      //    header line, callback function
+               int wrap, int Fheader, textwidget_callbackfunc_t CBfunc, ...);    //    wrap, header line, callback function
 void popup_report_header(zdialog *zd, int bold, ch *format, ...);                //  write non-scrolling header line
 void popup_report_write(zdialog *zd, int bold, ch *format, ...);                 //  write text line
 void popup_report_write2(zdialog *zd, int bold, ch *format, ...);                //  write text line and scroll to end
